********************************************************************************
*
*     A Comparative Analysis of Contract and Government  
* 	  Teachers in Sierra Leone: Profiles and Practices 
*
*     Stata .do file 3: Analysis
*
********************************************************************************
clear all
set more off
set mem 100m

***************************************
* Figure 1: ASC Overtime
***************************************
use "$cleandata_allyears.dta"
putexcel set "$output/figures.xlsx", sheet("Figure 1") modify
putexcel A1=("Figure 1. Contract vs Government Teachers, 2015-2022")
putexcel A2 = ("Year") B2 = ("Contract Count") C2 = ("Government Count") D2 = ("Contract Percent") E2 = ("Government Percent")

* Generate a new count variable for each teacher
gen count = 1

* Collapse data to get counts
collapse (sum) count, by(year teacher_type)

* Reshape the data to wide format for easy export
reshape wide count, i(year) j(teacher_type) 

* Calculate percentages
gen total = count0 + count1
gen percent_contract = 100 * count0 / total
gen percent_government = 100 * count1 / total

* Export results to Excel
local row = 3
forvalues i = 1/`=_N' {
    putexcel A`row' = year[`i'] B`row' = count0[`i'] C`row' = count1[`i'] D`row' = percent_contract[`i'] E`row' = percent_government[`i']
    local row = `row' + 1
}
***************************************
* Figure 2a: ASC District
****************************************
clear 
use "$cleandata_allyears.dta"
putexcel set "$output/figures.xlsx", sheet("Figure 2a") modify
putexcel A1 = "Figure 2a. School District Disaggregation, 2022"
putexcel A2 = ("District") B2 = ("Contract Count") C2 = ("Government Count") D2 = ("Contract Percent") E2 = ("Government Percent")

* Filter data for the year 2022
keep if year == 2022

* Generate a new count variable for each teacher
gen count = 1

* Collapse data to get counts
collapse (sum) count, by(district teacher_type)

* Reshape the data to wide format for easy export
reshape wide count, i(district) j(teacher_type) 

* Calculate percentages
gen total = count0 + count1
gen percent_contract = 100 * count0 / total
gen percent_government = 100 * count1 / total

* Export results to Excel
local row = 3
forvalues i = 1/`=_N' {
* Retrieve the label for the district value
    local district_value = district[`i']
    local district_label : label district `district_value'
    putexcel A`row' = "`district_value' (`district_label')" B`row' = count0[`i'] C`row' = count1[`i'] D`row' = percent_contract[`i'] E`row' = percent_government[`i']
    local row = `row' + 1
}
***************************************
* Figure 2a: ASC Level
****************************************
clear 
use "$cleandata_allyears.dta"
putexcel set "$output/figures.xlsx", sheet("Figure 2b") modify
putexcel A1 = "Figure 2b. School Level Disaggregation, 2022"
putexcel A2 = ("Level") B2 = ("Contract Count") C2 = ("Government Count") D2 = ("Contract Percent") E2 = ("Government Percent")

* Filter data for the year 2022
keep if year == 2022

* Generate a new count variable for each teacher
gen count = 1

* Collapse data to get counts
collapse (sum) count, by(level teacher_type)

* Reshape the data to wide format for easy export
reshape wide count, i(level) j(teacher_type) 

* Calculate percentages
gen total = count0 + count1
gen percent_contract = 100 * count0 / total
gen percent_government = 100 * count1 / total

* Export results to Excel
local row = 3
forvalues i = 1/`=_N' {
* Retrieve the label for the level value
    local level_value = level[`i']
    local level_label : label level `level_value'
    putexcel A`row' = "`level_value' (`level_label')" B`row' = count0[`i'] C`row' = count1[`i'] D`row' = percent_contract[`i'] E`row' = percent_government[`i']
    local row = `row' + 1
}
***************************************
* Figure 3: GEPD Training Topics
***************************************
clear
use "$cleandata/GEPD_final_analysis.dta"

* Open a new log to capture the output
log using "$output/figure3.log", text replace

* Define survey settings
svyset school_code [pw=teacher_weight_component], singleunit(certainty) strata(strata)

* Create the survey-weighted table
svy: tabulate training government, column

log close

***************************************
* Figure 4: GEPD TEACH - comparison to peers
***************************************
clear 
use "$cleandata/teach_peers.dta"
putexcel set "$output/figures.xlsx", sheet("Figure 4") modify
putexcel A1 = "Figure 4. Teach Income and Regional Peers"
putexcel A2 = ("Country") B2 = ("Variable") C2 = ("Mean")

* Export results to Excel
local row = 3
forval i = 1/`=_N' {
    local country = country_id[`i']
    local variable = var[`i']
    local mean = mean[`i']
* Retrieve the label for the level value
    local country_value = country_id[`i']
    local country_label : label country_id `country_value'
* Write the results to Excel
    putexcel A`row' = "`country_value' (`country_label')" ///
            B`row' = "`variable'" ///
            C`row' = "`mean'"
    local row = `row' + 1
}
***************************************
* Figure 5: GEPD Motivation for entering profession
***************************************
use "$cleandata/GEPD_final_analysis.dta"

* Open a new log to capture the output
log using "$output/figure5.log", text replace

* Define survey settings
svyset school_code[pw=teacher_weight_component], singleunit(certainty) strata(strata)

svy: tabulate motivation government, column

* Close the log file
log close

***************************************
* Table 2: GEPD Prof Dev Opps
***************************************
clear
use "$cleandata/GEPD_final_analysis.dta"
putexcel set "$output/tables.xlsx", sheet("Table 2") modify
putexcel A1 = "Dependent Variable" B1 = "Group" C1 = "Contract Mean" D1 = "Government Mean"

svyset school_code[pw=teacher_weight_component], singleunit(certainty) strata(strata)

* Define independent and dependent variables
local independent government teacher_urban teacher_rural teacher_male teacher_female teacher_untrained teacher_trained
local dependent induction practicum attended_training observed observed_feedback

* Initialize row counter
local row = 2

* Loop through each dependent variable
foreach dep in `dependent' {
    * Loop through each independent variable
    foreach indep in `independent' {
        * Perform survey mean with subgroup
		svy, subpop(if `indep' == 0): mean `dep'
		matrix contract_result = r(table)
        local contract_mean = contract_result[1,1]
		local contract_se = contract_result[1,2]
        
        svy, subpop(if `indep' == 1): mean `dep'
		matrix government_result = r(table)
        local government_mean = government_result[1,1]
		local government_se = government_result[1,2]
		
		* Calculate p-value for the difference in means
        local diff = `contract_mean' - `government_mean'
        local se_diff = sqrt(`contract_se'^2 + `government_se'^2)
        local t_stat = abs(`diff') / `se_diff'
        local p_value = 2 * ttail(e(df_r), `t_stat')
	
        * Write results to Excel
        putexcel A`row' = "`dep'" B`row' = "`indep'" C`row' = `contract_mean' D`row' = `government_mean' E`row' = `p_value'
        local row = `row' + 1
    }
}
***************************************
* Table 3: GEPD TEACH 
***************************************
clear
use "$cleandata/GEPD_final_analysis.dta"
putexcel set "$output/tables.xlsx", sheet("Table 3") modify
putexcel A1 = "Dependent Variable" B1 = "Group" C1 = "Contract Mean" D1 = "Government Mean"

svyset school_code[pw=g4_stud_weight_component], singleunit(certainty) strata(strata)

local independent government teacher_urban teacher_rural teacher_male teacher_female
local dependent supportive_envir positive_beh lesson_facil checks_understanding feedback critical_thinking autonomy perseverance social_collab_skills  
* Initialize row counter
local row = 2

* Loop through each dependent variable
foreach dep in `dependent' {
* Loop through each independent variable
    foreach indep in `independent' {
* Perform survey mean with subgroup
		svy, subpop(if `indep' == 0): mean `dep'
		matrix contract_result = r(table)
        local contract_mean = contract_result[1,1]
		local contract_se = contract_result[1,2]
        
        svy, subpop(if `indep' == 1): mean `dep'
		matrix government_result = r(table)
        local government_mean = government_result[1,1]
		local government_se = government_result[1,2]
		
* Calculate p-value for the difference in means
        local diff = `contract_mean' - `government_mean'
        local se_diff = sqrt(`contract_se'^2 + `government_se'^2)
        local t_stat = abs(`diff') / `se_diff'
        local p_value = 2 * ttail(e(df_r), `t_stat')
	
* Write results to Excel
        putexcel A`row' = "`dep'" B`row' = "`indep'" C`row' = `contract_mean' D`row' = `government_mean' E`row' = `p_value'
        local row = `row' + 1
    }
}
***************************************
* Table 4: GEPD Teacher Content Knowledge
***************************************
clear
use "$cleandata/GEPD_final_analysis.dta"
putexcel set "$output/tables.xlsx", sheet("Table 4") modify
putexcel A1 = "Dependent Variable" B1 = "Group" C1 = "Contract Mean" D1 = "Government Mean"

svyset school_code[pw=teacher_weight_component], singleunit(certainty) strata(strata)

local independent government teacher_urban teacher_rural teacher_male teacher_female
local dependent literacy_content_knowledge math_content_knowledge

* Initialize row counter
local row = 2

* Loop through each dependent variable
foreach dep in `dependent' {
* Loop through each independent variable
    foreach indep in `independent' {
* Perform survey mean with subgroup
		svy, subpop(if `indep' == 0): mean `dep'
		matrix contract_result = r(table)
        local contract_mean = contract_result[1,1]
		local contract_se = contract_result[1,2]
        
        svy, subpop(if `indep' == 1): mean `dep'
		matrix government_result = r(table)
        local government_mean = government_result[1,1]
		local government_se = government_result[1,2]
		
* Calculate p-value for the difference in means
        local diff = `contract_mean' - `government_mean'
        local se_diff = sqrt(`contract_se'^2 + `government_se'^2)
        local t_stat = abs(`diff') / `se_diff'
        local p_value = 2 * ttail(e(df_r), `t_stat')
	
* Write results to Excel
        putexcel A`row' = "`dep'" B`row' = "`indep'" C`row' = `contract_mean' D`row' = `government_mean' E`row' = `p_value'
        local row = `row' + 1
    }
}
***************************************
* Table 5: GEPD Student Content Knowledge
***************************************
clear
use "$cleandata/GEPD_final_analysis_students.dta"
putexcel set "$output/tables.xlsx", sheet("Table 5") modify
putexcel A1 = "Dependent Variable" B1 = "Group" C1 = "Contract Mean" D1 = "Government Mean"

svyset school_code[pw=g4_stud_weight_component], singleunit(certainty) strata(strata)

local independent government teacher_urban teacher_rural teacher_male teacher_female 
local dependent literacy_student_knowledge math_student_knowledge 

* Initialize row counter
local row = 2

* Loop through each dependent variable
foreach dep in `dependent' {
* Loop through each independent variable
    foreach indep in `independent' {
* Perform survey mean with subgroup
		svy, subpop(if `indep' == 0): mean `dep'
		matrix contract_result = r(table)
        local contract_mean = contract_result[1,1]
		local contract_se = contract_result[1,2]
        
        svy, subpop(if `indep' == 1): mean `dep'
		matrix government_result = r(table)
        local government_mean = government_result[1,1]
		local government_se = government_result[1,2]
		
* Calculate p-value for the difference in means
        local diff = `contract_mean' - `government_mean'
        local se_diff = sqrt(`contract_se'^2 + `government_se'^2)
        local t_stat = abs(`diff') / `se_diff'
        local p_value = 2 * ttail(e(df_r), `t_stat')
	
* Write results to Excel
        putexcel A`row' = "`dep'" B`row' = "`indep'" C`row' = `contract_mean' D`row' = `government_mean' E`row' = `p_value'
        local row = `row' + 1
    }
}
***************************************
* Table 6: GEPD Teacher Satisfaction
***************************************
clear
use "$cleandata/GEPD_final_analysis.dta"
putexcel set "$output/tables.xlsx", sheet("Table 6") modify
putexcel A1 = "Dependent Variable" B1 = "Group" C1 = "Contract Mean" D1 = "Government Mean"

svyset school_code[pw=teacher_weight_component], singleunit(certainty) strata(strata)

local independent government teacher_urban teacher_rural teacher_male teacher_female teacher_untrained teacher_trained
local dependent satisified_job satisfied_socialstatus

* Initialize row counter
local row = 2

* Loop through each dependent variable
foreach dep in `dependent' {
* Loop through each independent variable
    foreach indep in `independent' {
* Perform survey mean with subgroup
		svy, subpop(if `indep' == 0): mean `dep'
		matrix contract_result = r(table)
        local contract_mean = contract_result[1,1]
		local contract_se = contract_result[1,2]
        
        svy, subpop(if `indep' == 1): mean `dep'
		matrix government_result = r(table)
        local government_mean = government_result[1,1]
		local government_se = government_result[1,2]
		
* Calculate p-value for the difference in means
        local diff = `contract_mean' - `government_mean'
        local se_diff = sqrt(`contract_se'^2 + `government_se'^2)
        local t_stat = abs(`diff') / `se_diff'
        local p_value = 2 * ttail(e(df_r), `t_stat')
	
* Write results to Excel
        putexcel A`row' = "`dep'" B`row' = "`indep'" C`row' = `contract_mean' D`row' = `government_mean' E`row' = `p_value'
        local row = `row' + 1
    }
}
***************************************
* Table 7: GEPD Teacher Progression and Compensation
***************************************
clear
use "$cleandata/GEPD_final_analysis.dta"
putexcel set "$output/tables.xlsx", sheet("Table 7") modify
putexcel A1 = "Dependent Variable" B1 = "Group" C1 = "Contract Mean" D1 = "Government Mean"

svyset school_code[pw=teacher_weight_component], singleunit(certainty) strata(strata)

local independent government teacher_urban teacher_rural teacher_male teacher_female teacher_untrained teacher_trained
local dependent bonus progression

* Initialize row counter
local row = 2

* Loop through each dependent variable
foreach dep in `dependent' {
* Loop through each independent variable
    foreach indep in `independent' {
* Perform survey mean with subgroup
		svy, subpop(if `indep' == 0): mean `dep'
		matrix contract_result = r(table)
        local contract_mean = contract_result[1,1]
		local contract_se = contract_result[1,2]
        
        svy, subpop(if `indep' == 1): mean `dep'
		matrix government_result = r(table)
        local government_mean = government_result[1,1]
		local government_se = government_result[1,2]
		
* Calculate p-value for the difference in means
        local diff = `contract_mean' - `government_mean'
        local se_diff = sqrt(`contract_se'^2 + `government_se'^2)
        local t_stat = abs(`diff') / `se_diff'
        local p_value = 2 * ttail(e(df_r), `t_stat')
	
* Write results to Excel
        putexcel A`row' = "`dep'" B`row' = "`indep'" C`row' = `contract_mean' D`row' = `government_mean' E`row' = `p_value'
        local row = `row' + 1
    }
}
***************************************
* Table 8: Time on Task
***************************************
clear
use "$cleandata/GEPD_final_analysis.dta"
putexcel set "$output/tables.xlsx", sheet("Table 8") modify
putexcel A1 = "Dependent Variable" B1 = "Group" C1 = "Contract Mean" D1 = "Government Mean"

svyset school_code[pw=abs_weight_component], singleunit(certainty) strata(strata)

local independent government teacher_urban teacher_rural teacher_male teacher_female
local dependent absent absent_class absent_school

* Initialize row counter
local row = 2

* Loop through each dependent variable
foreach dep in `dependent' {
* Loop through each independent variable
    foreach indep in `independent' {
* Perform survey mean with subgroup
		svy, subpop(if `indep' == 0): mean `dep'
		matrix contract_result = r(table)
        local contract_mean = contract_result[1,1]
		local contract_se = contract_result[1,2]
        
        svy, subpop(if `indep' == 1): mean `dep'
		matrix government_result = r(table)
        local government_mean = government_result[1,1]
		local government_se = government_result[1,2]
		
* Calculate p-value for the difference in means
        local diff = `contract_mean' - `government_mean'
        local se_diff = sqrt(`contract_se'^2 + `government_se'^2)
        local t_stat = abs(`diff') / `se_diff'
        local p_value = 2 * ttail(e(df_r), `t_stat')
	
* Write results to Excel
        putexcel A`row' = "`dep'" B`row' = "`indep'" C`row' = `contract_mean' D`row' = `government_mean' E`row' = `p_value'
        local row = `row' + 1
    }
}
***************************************
* Annex A2: Summary Statistics
***************************************
clear
use "$cleandata/GEPD_final_analysis.dta"
putexcel set "$output/tables.xlsx", sheet("Table A2") modify
putexcel A1 = "Variable" B1 = "N (Gov=0)" C1 = "Mean (Gov=0)" D1 = "Std. Dev. (Gov=0)" E1 = "Min (Gov=0)" F1 = "Max (Gov=0)" ///
              G1 = "N (Gov=1)" H1 = "Mean (Gov=1)" I1 = "Std. Dev. (Gov=1)" J1 = "Min (Gov=1)" K1 = "Max (Gov=1)"

* Define variables to summarize
local vars government gender age grade subject trained1 service_years urban_rural

* Initialize row counter for Excel
local row = 2

* Loop through each variable to summarize and export to Excel
foreach var of local vars {
    * Get summary statistics for government = 0
    quietly summarize `var' if government == 0
    local N0 = r(N)
    local mean0 = r(mean)
    local sd0 = r(sd)
    local min0 = r(min)
    local max0 = r(max)
    
    * Get summary statistics for government = 1
    quietly summarize `var' if government == 1
    local N1 = r(N)
    local mean1 = r(mean)
    local sd1 = r(sd)
    local min1 = r(min)
    local max1 = r(max)
    
    * Write the results to Excel
    putexcel A`row' = "`var'" ///
            B`row' = `N0' C`row' = `mean0' D`row' = `sd0' E`row' = `min0' F`row' = `max0' ///
            G`row' = `N1' H`row' = `mean1' I`row' = `sd1' J`row' = `min1' K`row' = `max1'
    local row = `row' + 1
}
